.. cpiofile documentation master file

***********************************
Welcome to cpiofile's documentation!
***********************************

Contents of this document:

.. toctree::
   :maxdepth: 2

Cpiofile is a library which reads and writes unix format cpio archives.

Current features:

* In initial development ...

=====================================
 A Note on Supported Python Versions
=====================================

As I'm trying to straddle the 2 vs 3 jump, I'm relying on some of the
python-3 compatibility features from 2.6 and higher.  Supporting
earlier versions of python would be possible, but would make
supporting the python 2 vs 3 straddle somewhat more difficult.  I've
arbitrarily drawn my line in the sand at 2.6.

======
 TODO
======

.. todolist::

====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
